@@ -25,6 +25,7 @@
 #include <string.h>
 #include <unistd.h>
 
+#include <gtk/gtk.h>
 #include <glib/gi18n.h>
 
 #include "seahorse-gconf.h"
@@ -58,18 +59,18 @@ enum {
     N_COLS
 };
 
-static const SeahorseSetModelColumn column_info[] = {
-	{ "usage", G_TYPE_INT, "usage" },
-	{ "stock-id", G_TYPE_STRING, NULL },
-	{ "markup", G_TYPE_STRING, "name" },
-	{ "display-id", G_TYPE_STRING, "id" },
+static SeahorseSetModelColumn column_info[] = {
+	{ "usage", G_TYPE_UINT, "usage" },
+	{ "icon", G_TYPE_STRING, NULL },
+	{ "markup", G_TYPE_STRING, "label" },
+	{ "identifier", G_TYPE_STRING, "id" },
 	{ "validity-str", G_TYPE_STRING, "validity" },
 	{ "trust-str", G_TYPE_STRING, "trust" },
 	{ "type", G_TYPE_STRING, "type" },
 	{ "expires-str", G_TYPE_STRING, "expires" },
-	{ "validity", G_TYPE_INT, "validity" },
+	{ "validity", G_TYPE_UINT, "validity" },
 	{ "expires", G_TYPE_ULONG, "expires" },
-	{ "trust", G_TYPE_INT, "trust" }
+	{ "trust", G_TYPE_UINT, "trust" }
 };
 
 enum {
@@ -111,11 +112,10 @@ static void
 get_base_iter (SeahorseKeyManagerStore *skstore, GtkTreeIter *base_iter, 
                const GtkTreeIter *iter)
 {
-    GtkTreeIter i;
-    g_assert (skstore->priv->sort && skstore->priv->filter);
-    
-    gtk_tree_model_sort_convert_iter_to_child_iter (skstore->priv->sort, &i, (GtkTreeIter*)iter);
-    gtk_tree_model_filter_convert_iter_to_child_iter (skstore->priv->filter, base_iter, &i);
+	GtkTreeIter i;
+	g_return_if_fail (skstore->priv->sort && skstore->priv->filter);
+	gtk_tree_model_sort_convert_iter_to_child_iter (skstore->priv->sort, &i, (GtkTreeIter*)iter);
+	gtk_tree_model_filter_convert_iter_to_child_iter (skstore->priv->filter, base_iter, &i);
 }
 
 /* Given a base store iter, get the treeview iter */
@@ -127,6 +127,7 @@ get_upper_iter (SeahorseKeyManagerStore *skstore, GtkTreeIter *upper_iter,
     GtkTreePath *child_path, *path;
     gboolean ret;
     
+    g_return_val_if_fail (skstore->priv->filter, FALSE);
     child_path = gtk_tree_model_get_path (gtk_tree_model_filter_get_model (skstore->priv->filter), 
                                           (GtkTreeIter*)iter);
     g_return_val_if_fail (child_path != NULL, FALSE);
@@ -142,6 +143,7 @@ get_upper_iter (SeahorseKeyManagerStore *skstore, GtkTreeIter *upper_iter,
     if (!ret)
         return FALSE;
   
+    g_return_val_if_fail (skstore->priv->sort, FALSE);
     gtk_tree_model_sort_convert_child_iter_to_iter (skstore->priv->sort, upper_iter, &i);
     return TRUE;
 }
@@ -158,8 +160,7 @@ key_store_from_model (GtkTreeModel *model)
     if (SEAHORSE_IS_KEY_MANAGER_STORE (model))
         return SEAHORSE_KEY_MANAGER_STORE (model);
     
-    g_assert_not_reached ();
-    return NULL;
+    g_return_val_if_reached (NULL);
 }
 
 /* Given an iterator find the associated object */
@@ -171,6 +172,7 @@ object_from_iterator (GtkTreeModel* model, GtkTreeIter* iter)
 	/* Convert to base iter if necessary */
 	if (!SEAHORSE_IS_KEY_MANAGER_STORE (model)) {
 		SeahorseKeyManagerStore* skstore = key_store_from_model (model);
+		g_return_val_if_fail (SEAHORSE_IS_KEY_MANAGER_STORE (skstore), NULL);
 		get_base_iter (skstore, &i, iter);
         
 		iter = &i;
@@ -253,6 +255,7 @@ filter_callback (GtkTreeModel *model, GtkTreeIter *iter, gpointer data)
 static gboolean
 refilter_now (SeahorseKeyManagerStore* skstore)
 {
+    g_return_val_if_fail (skstore->priv->filter, FALSE);
     seahorse_set_refresh (SEAHORSE_SET_MODEL (skstore)->set);
     gtk_tree_model_filter_refilter (skstore->priv->filter);    
     skstore->priv->filter_stag = 0;
@@ -301,6 +304,7 @@ set_sort_to (SeahorseKeyManagerStore *skstore, const gchar *name)
     }
     
     if (id != -1) {
+        g_return_if_fail (skstore->priv->sort);
         sort = GTK_TREE_SORTABLE (skstore->priv->sort);
         gtk_tree_sortable_set_sort_column_id (sort, id, ord);
     }
@@ -317,7 +321,8 @@ sort_changed (GtkTreeSortable *sort, gpointer user_data)
     gchar* x;
     
     skstore = SEAHORSE_KEY_MANAGER_STORE (user_data);
-        
+    g_return_if_fail (skstore->priv->sort);
+    
     /* We have a sort so save it */
     if (gtk_tree_sortable_get_sort_column_id (sort, &id, &ord)) {
         if (id >= 0 && id < N_COLS) {
@@ -352,8 +357,8 @@ gconf_notification (GConfClient *gclient, guint id, GConfEntry *entry, GtkTreeVi
     g_assert (GTK_IS_TREE_VIEW (view));
     
     if (g_str_equal (key, KEY_MANAGER_SORT_KEY)) {
-        skstore = key_store_from_model (gtk_tree_view_get_model(view));
-        g_return_if_fail (skstore != NULL);
+        skstore = key_store_from_model (gtk_tree_view_get_model (view));
+        g_return_if_fail (SEAHORSE_IS_KEY_MANAGER_STORE (skstore));
         set_sort_to (skstore, gconf_value_get_string (gconf_entry_get_value (entry)));
     }
     
@@ -398,24 +403,46 @@ append_text_column (SeahorseKeyManagerStore *skstore, GtkTreeView *view,
 static char *
 xds_get_atom_value (GdkDragContext *context)
 {
+  	#if GTK_CHECK_VERSION (2,22,0)
+        GdkWindow *source_window;
+    #endif
 	char *ret;
 
 	g_return_val_if_fail (context != NULL, NULL);
-	g_return_val_if_fail (context->source_window != NULL, NULL);
+	
+	#if GTK_CHECK_VERSION (2,22,0)
+	    source_window = gdk_drag_context_get_source_window (context);
+	    g_return_val_if_fail (source_window != NULL, NULL);
+	#else
+	    g_return_val_if_fail (context->source_window != NULL, NULL);
+    #endif
+    
+    #if GTK_CHECK_VERSION (2,22,0)
+        if (gdk_property_get (source_window,
+    #else
+	    if (gdk_property_get (context->source_window,
+    #endif
+			      XDS_ATOM, TEXT_ATOM,
+			      0, MAX_XDS_ATOM_VAL_LEN,
+			      FALSE, NULL, NULL, NULL,
+			      (unsigned char **) &ret))
+		return ret;
 
-	gdk_property_get (context->source_window,
-			  XDS_ATOM, TEXT_ATOM,
-			  0, MAX_XDS_ATOM_VAL_LEN,
-			  FALSE, NULL, NULL, NULL,
-			  (unsigned char **) &ret);
-
-	return ret;
+	return NULL;
 }
 
 static gboolean
 xds_context_offers_target (GdkDragContext *context, GdkAtom target)
 {
-	return (g_list_find (context->targets, target) != NULL);
+    #if GTK_CHECK_VERSION (2,22,0)
+        GList *targets;
+
+    	targets = gdk_drag_context_list_targets (context);
+
+    	return (g_list_find (targets, target) != NULL);
+    #else
+	    return (g_list_find (context->targets, target) != NULL);
+    #endif
 }
 
 static gboolean
@@ -441,6 +468,10 @@ static gboolean
 drag_begin (GtkWidget *widget, GdkDragContext *context, SeahorseKeyManagerStore *skstore)
 {
 	GtkTreeView *view = GTK_TREE_VIEW (widget);
+	
+	#if GTK_CHECK_VERSION (2,22,0)
+        GdkWindow *source_window;
+    #endif
     
 	DBG_PRINT (("drag_begin -->\n"));
 
@@ -451,10 +482,20 @@ drag_begin (GtkWidget *widget, GdkDragContext *context, SeahorseKeyManagerStore
 	
 	g_list_free (skstore->priv->drag_objects);
 	skstore->priv->drag_objects = seahorse_key_manager_store_get_selected_objects (view);
-	if (skstore->priv->drag_objects)
-		gdk_property_change (context->source_window, XDS_ATOM, TEXT_ATOM, 
+	
+    #if GTK_CHECK_VERSION (2,22,0)
+        if (skstore->priv->drag_objects) {
+		    source_window = gdk_drag_context_get_source_window (context);
+		    gdk_property_change (source_window, XDS_ATOM, TEXT_ATOM,
+    #else
+	    if (skstore->priv->drag_objects)
+		    gdk_property_change (context->source_window, XDS_ATOM, TEXT_ATOM, 
+	#endif
 		                     8, GDK_PROP_MODE_REPLACE, (guchar*)XDS_FILENAME,
 		                     strlen (XDS_FILENAME));
+    #if GTK_CHECK_VERSION (2,22,0)
+        }
+    #endif
 	
 	DBG_PRINT (("drag_begin <--\n"));
 	return skstore->priv->drag_objects ? TRUE : FALSE;
@@ -607,7 +648,7 @@ drag_data_get (GtkWidget *widget, GdkDragContext *context, GtkSelectionData *sel
 			skstore->priv->drag_destination = g_path_get_dirname (destination);
 			g_free (destination);
 		
-			gtk_selection_data_set (selection_data, selection_data->target, 8, (guchar*)"S", 1);
+			gtk_selection_data_set (selection_data, gtk_selection_data_get_target (selection_data), 8, (guchar*)"S", 1);
 			ret = TRUE;
 		}
 		
@@ -630,7 +671,7 @@ drag_end (GtkWidget *widget, GdkDragContext *context, SeahorseKeyManagerStore *s
 	if (skstore->priv->drag_destination && !skstore->priv->drag_error) {
 		g_return_if_fail (skstore->priv->drag_objects);
 	
-		name = seahorse_util_filename_for_keys (skstore->priv->drag_objects);
+		name = seahorse_util_filename_for_objects (skstore->priv->drag_objects);
 		g_return_if_fail (name);
 	
 		filename = g_build_filename (skstore->priv->drag_destination, name, NULL);
@@ -744,10 +785,17 @@ static void
 seahorse_key_manager_store_finalize (GObject *gobject)
 {
     SeahorseKeyManagerStore *skstore = SEAHORSE_KEY_MANAGER_STORE (gobject);
+
+    if (skstore->priv->sort) {
+        g_signal_handlers_disconnect_by_func (skstore->priv->sort, sort_changed, skstore);
+        g_object_remove_weak_pointer (G_OBJECT (skstore->priv->sort), (gpointer*)&skstore->priv->sort);
+        skstore->priv->sort = NULL;
+    }
     
-    /* These were allocated in the constructor */
-    g_object_unref (skstore->priv->sort);
-    g_object_unref (skstore->priv->filter);
+    if (skstore->priv->filter) {
+        g_object_remove_weak_pointer (G_OBJECT (skstore->priv->filter), (gpointer*)&skstore->priv->filter);
+        skstore->priv->filter = NULL;
+    }
      
     /* Allocated in property setter */
     g_free (skstore->priv->filter_text); 
@@ -863,7 +911,9 @@ seahorse_key_manager_store_new (SeahorseSet *skset, GtkTreeView *view)
     if ((sort = seahorse_gconf_get_string (KEY_MANAGER_SORT_KEY)) != NULL) {
         set_sort_to (skstore, sort);
         g_free (sort);
-    }  
+    } 
+    
+    gtk_tree_view_set_enable_search (view, FALSE);
     
     seahorse_gconf_notify_lazy (LISTING_SCHEMAS, (GConfClientNotifyFunc)gconf_notification, 
                                 view, GTK_WIDGET (view));
@@ -878,6 +928,12 @@ seahorse_key_manager_store_new (SeahorseSet *skset, GtkTreeView *view)
     gtk_drag_source_set (GTK_WIDGET (view), GDK_BUTTON1_MASK,
                          store_targets, G_N_ELEMENTS (store_targets), GDK_ACTION_COPY);
 
+    /* We keep track of these but not as a strong reference */
+    g_object_add_weak_pointer (G_OBJECT (skstore->priv->filter), (gpointer*)&skstore->priv->filter);
+    g_object_unref (skstore->priv->filter);
+    g_object_add_weak_pointer (G_OBJECT (skstore->priv->sort), (gpointer*)&skstore->priv->sort);
+    g_object_unref (skstore->priv->sort);
+    
     return skstore;
 }
 
@@ -902,6 +958,7 @@ seahorse_key_manager_store_get_all_objects (GtkTreeView *view)
     
     g_return_val_if_fail (GTK_IS_TREE_VIEW (view), NULL);
     skstore = key_store_from_model (gtk_tree_view_get_model (view));
+    g_return_val_if_fail (SEAHORSE_IS_KEY_MANAGER_STORE (skstore), NULL);
     return seahorse_set_get_objects (SEAHORSE_SET_MODEL (skstore)->set);
 }
 
